'use client'

import { useState, useEffect } from 'react'
import { FiSave } from 'react-icons/fi'
import DashboardLayout from '@/components/layout/DashboardLayout'
import { useParams } from 'next/navigation'
import { tableService } from '@/services/api'
import { useUser } from '@/contexts/UserContext'
import Modal from '@/components/ui/Modal'

interface Table {
  id: number
  name: string
}

export default function EditTablePage() {
  const params = useParams()
  const [tableName, setTableName] = useState('')
  const { user } = useUser()
  const [table, setTable] = useState<Table | null>(null)
  const [success, setSuccess] = useState(false)
  const [error, setError] = useState<string | null>(null)

  const fetchTable = async () => {
    const response = await tableService.show(params.id as string, user?.token || '')
    console.log(response.data)
    setTable(response.data.table)
    setTableName(response.data.table.name)
  }

  useEffect(() => {
    fetchTable()
  }, [params.id])

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault()
    try {
      const response = await tableService.update(params.id as string, tableName, user?.token || '')
      setSuccess(true)
    } catch (err) {
      setError('Masa bilgileri güncellenirken bir hata oluştu')
      console.error('Masa güncelleme hatası:', err)
    }
  }

  return (
    <DashboardLayout>
      <div className="w-full mx-auto">
        <div className="bg-white/50 dark:bg-slate-800/50 backdrop-blur-sm rounded-3xl shadow-lg border border-slate-200/50 dark:border-slate-700/50">
          <div className="p-6 border-b border-slate-200/50 dark:border-slate-700/50">
            <h2 className="text-xl font-bold text-slate-800 dark:text-white">
              Masa Düzenle
            </h2>
            <p className="text-sm text-slate-500 dark:text-slate-400 mt-1">
              Masa bilgilerini güncellemek için formu doldurun
            </p>
          </div>

          <form onSubmit={handleSubmit} className="p-6 space-y-6">
            <div>
              <label htmlFor="tableName" className="block text-sm font-medium text-slate-700 dark:text-slate-300 mb-2">
                Masa Adı
              </label>
              <input
                id="tableName"
                name='tableName'
                type="text"
                value={tableName}
                onChange={(e) => setTableName(e.target.value)}
                className="w-full px-4 py-2.5 rounded-xl border border-slate-200/50 dark:border-slate-700/50 
                         bg-white/50 dark:bg-slate-700/50 backdrop-blur-sm
                         text-slate-800 dark:text-white
                         focus:outline-none focus:ring-2 focus:ring-fuchsia-500/50
                         transition-all placeholder-slate-400 dark:placeholder-slate-500"
                placeholder="Örn: Masa 8"
                required
              />
            </div>

            <div className="flex justify-end">
              <button
                type="submit"
                className="px-6 py-2.5 text-sm font-medium text-white 
                         bg-gradient-to-r from-fuchsia-500 to-purple-600 
                         rounded-xl hover:opacity-90 transition-all 
                         shadow-lg shadow-fuchsia-500/25
                         flex items-center gap-2"
              >
                <FiSave className="w-4 h-4" />
                <span>Kaydet</span>
              </button>
            </div>
          </form>
        </div>
      </div>
      {success && (
        <Modal
          isOpen={!!success}
          onClose={() => setSuccess(false)}
          title="Başarılı"
          message="Masa bilgileri güncellendi"
        />
      )}
      {error && (
        <Modal
          isOpen={!!error}
          onClose={() => setError(null)}
          title="Hata"
          message={error}
        />
      )}
    </DashboardLayout>
  )
} 